@@ -1,3 +1,4 @@
+import math
 from typing import List
 import itertools
 
@@ -20,10 +21,18 @@ def all_indxs_in_lst(lst: List, value) -> List[int]:
             break
     return idxs
 
-if __name__ == "__main__":
-    import random as rnd
-    l_o_l = [[x for x in range(rnd.randint(5, 10))] for y in range(rnd.randint(5, 10))]
+def next_perfect_square_rt(n: int) -> int:
+    int_root_n = int(math.sqrt(n))
+    if int_root_n == n:
+        return n
+    return int_root_n + 1
 
-    print(l_o_l)
-    print(flattened_list_of_lists(l_o_l))
-    print(flattened_list_of_lists(l_o_l, unique=True))
+if __name__ == "__main__":
+    # import random as rnd
+    # l_o_l = [[x for x in range(rnd.randint(5, 10))] for y in range(rnd.randint(5, 10))]
+    #
+    # print(l_o_l)
+    # print(flattened_list_of_lists(l_o_l))
+    # print(flattened_list_of_lists(l_o_l, unique=True))
+
+    print(next_perfect_square(9))
\ No newline at end of file
